# randLAX

**randLAX** is a Python package that provides randomized linear algebra routines built on top of [JAX](https://github.com/google/jax).

## Features

- Efficient randomized methods for (generalized) hermetian eigenvalue decomposition.
- B-inner product based orthonormalization routines.

## Installation

You can install the package using pip:

```bash
pip install randLAX
